==> mongodb-src-r5.0.7.tar.gz: mongodb-src-r5.0.7/src/mongo/db/s/transaction_coordinator_worker_curop_repository.h <==
/**
 *    Copyright (C) 2019-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */
#pragma once

#include "mongo/db/curop.h"

namespace mongo {

class TransactionCoordinatorWorkerCurOpRepository {
public:
    TransactionCoordinatorWorkerCurOpRepository() {}
    virtual ~TransactionCoordinatorWorkerCurOpRepository() {}

    enum class CoordinatorAction {
        kWritingParticipantList,
        kSendingPrepare,
        kWritingDecision,
        kSendingCommit,
        kSendingAbort,
        kDeletingCoordinatorDoc
    };

    /**
     * Associates the two phase commit coordinator transaction information with the
     * OperationContext instance.
     *
     * This method takes the associated client lock from the OperationContext.
     */
    virtual void set(OperationContext* opCtx,
                     const LogicalSessionId& lsid,
                     const TxnNumber txnNumber,
                     const CoordinatorAction action) = 0;

    /**
     * Output the state into BSON previously associated with this OperationContext instance.
     */
    virtual void reportState(OperationContext* opCtx, BSONObjBuilder* parent) const = 0;
};

std::shared_ptr<TransactionCoordinatorWorkerCurOpRepository>
getTransactionCoordinatorWorkerCurOpRepository();

}  // namespace mongo

==> mongodb-src-r5.1.1.tar.gz: mongodb-src-r5.1.1/src/mongo/db/s/transaction_coordinator_worker_curop_repository.h <==
/**
 *    Copyright (C) 2019-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */
#pragma once

#include "mongo/db/curop.h"

namespace mongo {

class TransactionCoordinatorWorkerCurOpRepository {
public:
    TransactionCoordinatorWorkerCurOpRepository() {}
    virtual ~TransactionCoordinatorWorkerCurOpRepository() {}

    enum class CoordinatorAction {
        kWritingParticipantList,
        kSendingPrepare,
        kWritingDecision,
        kSendingCommit,
        kSendingAbort,
        kDeletingCoordinatorDoc
    };

    /**
     * Associates the two phase commit coordinator transaction information with the
     * OperationContext instance.
     *
     * This method takes the associated client lock from the OperationContext.
     */
    virtual void set(OperationContext* opCtx,
                     const LogicalSessionId& lsid,
                     TxnNumber txnNumber,
                     CoordinatorAction action) = 0;

    /**
     * Output the state into BSON previously associated with this OperationContext instance.
     */
    virtual void reportState(OperationContext* opCtx, BSONObjBuilder* parent) const = 0;
};

std::shared_ptr<TransactionCoordinatorWorkerCurOpRepository>
getTransactionCoordinatorWorkerCurOpRepository();

}  // namespace mongo
